"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const builtin_modules_1 = __importDefault(require("builtin-modules"));
const react_to_typescript_definitions_1 = require("react-to-typescript-definitions");
const rollup_1 = require("rollup");
const rollup_plugin_commonjs_1 = __importDefault(require("rollup-plugin-commonjs"));
const rollup_plugin_json_1 = __importDefault(require("rollup-plugin-json"));
const rollup_plugin_node_resolve_1 = __importDefault(require("rollup-plugin-node-resolve"));
const acorn_plugins_1 = require("./acorn-plugins");
const debug_1 = require("./debug");
const rollup_plugin_replace_with_empty_module_1 = require("./rollup-plugin-replace-with-empty-module");
const defaultBundleOptions = {
    external: builtin_modules_1.default.concat(['react', 'prop-types']),
    replaceWithEmptyModulePatterns: ['**/*.css'],
};
async function generateBundleCode(input, options) {
    options = Object.assign({}, defaultBundleOptions, options);
    const bundle = await rollup_1.rollup({
        input,
        external: options.external,
        plugins: [
            rollup_plugin_replace_with_empty_module_1.replaceWithEmptyModule(options.replaceWithEmptyModulePatterns),
            rollup_plugin_node_resolve_1.default({
                extensions: ['.js', '.jsx'],
                jsnext: true,
                preferBuiltins: true,
            }),
            rollup_plugin_json_1.default(),
            rollup_plugin_commonjs_1.default(),
        ],
        preserveSymlinks: false,
        acorn: {
            plugins: {
                jsx: true,
                staticClassPropertyInitializer: true,
            },
        },
        acornInjectPlugins: [acorn_plugins_1.injectPlugins],
    });
    const { code } = await bundle.generate({ format: 'es' });
    debug_1.debug(code);
    return code;
}
async function generateTypings(moduleName, input, options) {
    const code = await generateBundleCode(input, options);
    const typings = react_to_typescript_definitions_1.generateFromSource(moduleName, code);
    return normalizeLineEndings(typings);
}
exports.generateTypings = generateTypings;
function normalizeLineEndings(text) {
    return text.replace(/\r\n/g, '\n');
}
//# sourceMappingURL=generate.js.map